---
name: Feature request
about: Suggest an idea for this project
title: "[Feature Request]"
labels: ''
assignees: ''

---

**Is your feature request related to a problem? Please describe your use case.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]
It would be very nice to provide some code snippet to explain your use case.

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Additional context**
Add any other context about the feature request here. This might be which part of source code to modify or some information you think it might help.
